databox.core


box?clj

(box? box)
source

distinctclj

(distinct)
source

distinct-byclj

(distinct-by f)
source

exceptionclj

(exception v)
source

failureclj

(failure ex)
source

failure?clj

(failure? box)
source

filterclj

(filter pred)

filter transducer for filterling boxed data by the contained value.

filter transducer for filterling boxed data by the contained value.
sourceraw docstring

mapclj

(map data & args)
source

mapcatclj

(mapcat data & args)
source

mapletcljmacro

(maplet & args)
source

strip-default-keysclj

(strip-default-keys boxed)
source

successclj

(success value)
source

success-valueclj

(success-value v)
source

success?clj

(success? box)
source

unboxclj

(unbox v)
source

valueclj

(value v)
source

cljdoc builds & hosts documentation for Clojure/Script libraries